summaryrefslogtreecommitdiff
path: root/source4/include
diff options
context:
space:
mode:
authorStefan Metzmacher <metze@samba.org>2004-07-05 23:28:49 +0000
committerGerald (Jerry) Carter <jerry@samba.org>2007-10-10 12:56:51 -0500
commit4f0e5e069064c11a8efc407cd42412d38534d0d2 (patch)
treefcf4d3913183525653af213c6c15abbb8b9c6754 /source4/include
parent8bebc53df8ff46e801ed1258206126f6ebe9a1c3 (diff)
downloadsamba-4f0e5e069064c11a8efc407cd42412d38534d0d2.tar.gz
samba-4f0e5e069064c11a8efc407cd42412d38534d0d2.tar.bz2
samba-4f0e5e069064c11a8efc407cd42412d38534d0d2.zip
r1345: add extended security spnego support to the smb client
code set lp_use_spnego = False, because I can't get it working yet but I commit it so others can help me metze (This used to be commit 2445cceba9ab9bd928c8bc50927a39509e4526b0)
Diffstat (limited to 'source4/include')
-rw-r--r--source4/include/cli_context.h28
1 files changed, 15 insertions, 13 deletions
diff --git a/source4/include/cli_context.h b/source4/include/cli_context.h
index 24dcfe7235..930017bb26 100644
--- a/source4/include/cli_context.h
+++ b/source4/include/cli_context.h
@@ -29,21 +29,12 @@ struct cli_request; /* forward declare */
struct cli_session; /* forward declare */
struct cli_transport; /* forward declare */
-typedef struct smb_sign_info {
- void (*sign_outgoing_message)(struct cli_request *req);
- BOOL (*check_incoming_message)(struct cli_request *req);
- void (*free_signing_context)(struct cli_transport *transport);
- void *signing_context;
-
- BOOL doing_signing;
-} smb_sign_info;
-
/* context that will be and has been negotiated between the client and server */
struct cli_negotiate {
/*
* negotiated maximum transmit size - this is given to us by the server
*/
- uint_t max_xmit;
+ uint32_t max_xmit;
/* maximum number of requests that can be multiplexed */
uint16_t max_mux;
@@ -51,16 +42,24 @@ struct cli_negotiate {
/* the negotiatiated protocol */
enum protocol_types protocol;
- int sec_mode; /* security mode returned by negprot */
+ uint8_t sec_mode; /* security mode returned by negprot */
+ uint8_t key_len;
+ DATA_BLOB server_guid; /* server_guid */
DATA_BLOB secblob; /* cryptkey or negTokenInit blob */
uint32_t sesskey;
- smb_sign_info sign_info;
+ struct {
+ void (*sign_outgoing_message)(struct cli_request *req);
+ BOOL (*check_incoming_message)(struct cli_request *req);
+ void (*free_signing_context)(struct cli_transport *transport);
+ void *signing_context;
+ BOOL doing_signing;
+ } sign_info;
/* capabilities that the server reported */
uint32_t capabilities;
- int server_zone;
+ int16_t server_zone;
time_t server_time;
uint_t readbraw_supported:1;
uint_t writebraw_supported:1;
@@ -187,6 +186,9 @@ struct cli_session {
uint32_t pid;
DATA_BLOB user_session_key;
+
+ /* the spnego context if we use extented security */
+ struct gensec_security *gensec;
};
/*